@@ -16,7 +16,9 @@ def test_get_attachment_field(odoo_session):
 
 def test_get_attachment_bytes(odoo_session):
     bin = bytes("hello", 'ascii')
-    value = odoo_data.get_attachment(odoo_session['res.partner'], odoo_data.format_binary(bin))
+    value = odoo_data.get_attachment(
+        odoo_session['res.partner'], encoded_value=odoo_data.format_binary(bin)
+    )
     assert bin == value
 
 
